==> xlniuxdata-jinzuan-1.0.4-20141021.062936-1-sources.jar: com/xunlei/niux/data/jinzuan/vo/MemberDetail.java <==
package com.xunlei.niux.data.jinzuan.vo;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;


/**
 * 金钻详情
 * @author lisu
 * 2014-02-27
 */
@Table(tableName="jinzuan_memberdetail",pkFieldName="seqId",pkFieldAssign=false)
public class MemberDetail {
	

	private Long seqId;
    private Long userId;
    private String actNo;
    private String orderId;
    private Integer dayNum;
    private String orderTime;
    private String orderStartDate;
    private String orderEndDate;
    private Integer memberStatus;
    
    

	@Column(columnName="seqId",isWhereColumn=true,operator=Operator.GE)
	private Long fromSeqId;          
    @Column(columnName="seqId",isWhereColumn=true,operator=Operator.LT)
	private Long toSeqId;         
	@Column(columnName="orderTime",isWhereColumn=true,operator=Operator.GE)
	private String fromOrderTime;
	@Column(columnName="orderTime",isWhereColumn=true,operator=Operator.LT)
	private String toOrderTime;
	
    

    public Integer getMemberStatus() {
		return memberStatus;
	}
	public void setMemberStatus(Integer memberStatus) {
		this.memberStatus = memberStatus;
	}
	public Long getToSeqId() {
		return toSeqId;
	}
	public void setToSeqId(Long toSeqId) {
		this.toSeqId = toSeqId;
	}
	public Long getFromSeqId() {
		return fromSeqId;
	}
	public void setFromSeqId(Long fromSeqId) {
		this.fromSeqId = fromSeqId;
	}
	public String getFromOrderTime() {
		return fromOrderTime;
	}
	public void setFromOrderTime(String fromOrderTime) {
		this.fromOrderTime = fromOrderTime;
	}
	public String getToOrderTime() {
		return toOrderTime;
	}
	public void setToOrderTime(String toOrderTime) {
		this.toOrderTime = toOrderTime;
	}    
    public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public Long getUserId() {
		return userId;
	}
	public void setUserId(Long userId) {
		this.userId = userId;
	}
	public String getActNo() {
		return actNo;
	}
	public void setActNo(String actNo) {
		this.actNo = actNo;
	}
	public String getOrderId() {
		return orderId;
	}
	public void setOrderId(String orderId) {
		this.orderId = orderId;
	}
	public Integer getDayNum() {
		return dayNum;
	}
	public void setDayNum(Integer dayNum) {
		this.dayNum = dayNum;
	}
	public String getOrderTime() {
		return orderTime;
	}
	public void setOrderTime(String orderTime) {
		this.orderTime = orderTime;
	}
	public String getOrderStartDate() {
		return orderStartDate;
	}
	public void setOrderStartDate(String orderStartDate) {
		this.orderStartDate = orderStartDate;
	}
	public String getOrderEndDate() {
		return orderEndDate;
	}
	public void setOrderEndDate(String orderEndDate) {
		this.orderEndDate = orderEndDate;
	}

          
}

==> xlniuxdata-jinzuan-1.0.7-20151217.075436-3-sources.jar: com/xunlei/niux/data/jinzuan/vo/MemberDetail.java <==
package com.xunlei.niux.data.jinzuan.vo;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;


/**
 * 金钻详情
 * @author lisu
 * 2014-02-27
 */
@Table(tableName="jinzuan_memberdetail",pkFieldName="seqId",pkFieldAssign=false)
public class MemberDetail {
	

	private Long seqId;
    private Long userId;
    private String actNo;
    private String orderId;
    private Integer dayNum;
    private String orderTime;
    private String orderStartDate;
    private String orderEndDate;
    private Integer memberStatus;
    private Integer duobaoStatus;
    
    

	@Column(columnName="seqId",isWhereColumn=true,operator=Operator.GE)
	private Long fromSeqId;          
    @Column(columnName="seqId",isWhereColumn=true,operator=Operator.LT)
	private Long toSeqId;         
	@Column(columnName="orderTime",isWhereColumn=true,operator=Operator.GE)
	private String fromOrderTime;
	@Column(columnName="orderTime",isWhereColumn=true,operator=Operator.LT)
	private String toOrderTime;
	
    
	public Integer getDuobaoStatus() {
		return duobaoStatus;
	}
	public void setDuobaoStatus(Integer duobaoStatus) {
		this.duobaoStatus = duobaoStatus;
	}
	public Integer getMemberStatus() {
		return memberStatus;
	}
	public void setMemberStatus(Integer memberStatus) {
		this.memberStatus = memberStatus;
	}
	public Long getToSeqId() {
		return toSeqId;
	}
	public void setToSeqId(Long toSeqId) {
		this.toSeqId = toSeqId;
	}
	public Long getFromSeqId() {
		return fromSeqId;
	}
	public void setFromSeqId(Long fromSeqId) {
		this.fromSeqId = fromSeqId;
	}
	public String getFromOrderTime() {
		return fromOrderTime;
	}
	public void setFromOrderTime(String fromOrderTime) {
		this.fromOrderTime = fromOrderTime;
	}
	public String getToOrderTime() {
		return toOrderTime;
	}
	public void setToOrderTime(String toOrderTime) {
		this.toOrderTime = toOrderTime;
	}    
    public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public Long getUserId() {
		return userId;
	}
	public void setUserId(Long userId) {
		this.userId = userId;
	}
	public String getActNo() {
		return actNo;
	}
	public void setActNo(String actNo) {
		this.actNo = actNo;
	}
	public String getOrderId() {
		return orderId;
	}
	public void setOrderId(String orderId) {
		this.orderId = orderId;
	}
	public Integer getDayNum() {
		return dayNum;
	}
	public void setDayNum(Integer dayNum) {
		this.dayNum = dayNum;
	}
	public String getOrderTime() {
		return orderTime;
	}
	public void setOrderTime(String orderTime) {
		this.orderTime = orderTime;
	}
	public String getOrderStartDate() {
		return orderStartDate;
	}
	public void setOrderStartDate(String orderStartDate) {
		this.orderStartDate = orderStartDate;
	}
	public String getOrderEndDate() {
		return orderEndDate;
	}
	public void setOrderEndDate(String orderEndDate) {
		this.orderEndDate = orderEndDate;
	}

          
}
